@@ -2,7 +2,7 @@
  *
  *  Connection Manager
  *
- *  Copyright (C) 2007-2010  Intel Corporation. All rights reserved.
+ *  Copyright (C) 2007-2012  Intel Corporation. All rights reserved.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License version 2 as
@@ -32,36 +32,16 @@ extern "C" {
  * @short_description: Functions for registering resolver modules
  */
 
-int connman_resolver_append(const char *interface, const char *domain,
+int connman_resolver_append(int index, const char *domain,
 							const char *server);
-int connman_resolver_append_lifetime(const char *interface, const char *domain,
+int connman_resolver_append_lifetime(int index, const char *domain,
 				     const char *server, unsigned int lifetime);
-int connman_resolver_remove(const char *interface, const char *domain,
+int connman_resolver_remove(int index, const char *domain,
 							const char *server);
-int connman_resolver_remove_all(const char *interface);
-
-int connman_resolver_append_public_server(const char *server);
-int connman_resolver_remove_public_server(const char *server);
+int connman_resolver_remove_all(int index);
 
 void connman_resolver_flush(void);
 
-#define CONNMAN_RESOLVER_PRIORITY_LOW      -100
-#define CONNMAN_RESOLVER_PRIORITY_DEFAULT     0
-#define CONNMAN_RESOLVER_PRIORITY_HIGH      100
-
-struct connman_resolver {
-	const char *name;
-	int priority;
-	int (*append) (const char *interface, const char *domain,
-							const char *server);
-	int (*remove) (const char *interface, const char *domain,
-							const char *server);
-	void (*flush) (void);
-};
-
-int connman_resolver_register(struct connman_resolver *resolver);
-void connman_resolver_unregister(struct connman_resolver *resolver);
-
 #ifdef __cplusplus
 }
 #endif
